MutualProximity — hubness 0.21a1 documentation

# MutualProximity

class `hubness.reduction.` `MutualProximity`(k: int = 5, method: str = 'normal', verbose: int = 0)

  Bases: `object`

  Hubness reduction with Mutual Proximity.

  Methods Summary

  `fit`(neigh_dist, neigh_ind, *args, **kwargs) |
  `transform`(neigh_dist, neigh_ind, *args, **kwargs) |

  Methods Documentation

  `fit`(neigh_dist, neigh_ind, *args, **kwargs) → hubness.reduction.mutual_proximity.MutualProximity
  `transform`(neigh_dist, neigh_ind, *args, **kwargs)